from preprocessing import parse_file
from local_search import multistart_local_search
from simulated_annealing import simulated_annealing
from time import time
from argparse import ArgumentParser


def execute_algorithm(args, n, m, data):
    if args.algorithm == "annealing":
        return simulated_annealing(n, m, data, max_iterations=100)
    return multistart_local_search(n, m, data)


def show_results(solution, time_delta):
    duplicates = solution.duplicated().any()
    print(solution)
    print(f"Total distance: {solution.fitness.values[0]}")
    if not duplicates:
        print("No duplicates found")
    print(f"Execution time: {time_delta}")


def parse_arguments():
    parser = ArgumentParser()
    parser.add_argument("file", help="dataset of choice")
    parser.add_argument("algorithm", choices=["annealing", "multisearch"])
    return parser.parse_args()


def main():
    args = parse_arguments()
    n, m, data = parse_file(args.file)
    start_time = time()
    solutions = execute_algorithm(args, n, m, data)
    end_time = time()
    show_results(solutions, time_delta=end_time - start_time)


if __name__ == "__main__":
    main()
